@@ -2,9 +2,9 @@ import numpy as np
 import matplotlib.pylab as plt
 import warnings
 import os
-from pathlib import Path
+from pathlib import Path, PurePath
 from ephysiopy.common.ephys_generic import PosCalcsGeneric
-from ephysiopy.openephys2py.OESettings import Settings, OEStructure
+from ephysiopy.openephys2py.OESettings import Settings
 from ephysiopy.visualise.plotting import FigureMaker
 
 
@@ -17,14 +17,31 @@ def fileContainsString(pname: str, searchStr: str) -> bool:
         with open(pname, 'r') as f:
             strs = f.read()
         lines = strs.split('\n')
+        found = False
         for line in lines:
             if searchStr in line:
-                return True
-            else:
-                return False
+                found = True
+        return found
     else:
         return False
 
+
+def loadTrackingPluginData(pname: Path) -> np.array:
+    dt = np.dtype(
+        {'x': (np.single, 0),
+         'y': (np.single, 4),
+         'w': (np.single, 8),
+         'h': (np.single, 12)})
+    data_array = np.load(pname)
+    new_array = data_array.view(dtype=dt).copy()
+    w = new_array['w'][0]
+    h = new_array['h'][0]
+    x = new_array['x'] * w
+    y = new_array['y'] * h
+    pos_data = np.array([np.ravel(x), np.ravel(y)]).T
+    return pos_data
+
+
 class KiloSortSession(object):
     """
     Loads and processes data from a Kilosort session.
@@ -103,7 +120,8 @@ class KiloSortSession(object):
         """
         # if self.cluster_id is None:
         #     print(f"Searching {os.path.join(self.fname_root)} and...")
-        #     warnings.warn("No cluster_groups.tsv or cluster_group.csv file was found.\
+        #     warnings.warn("No cluster_groups.tsv or cluster_group.csv file
+        # was found.\
         #         Have you manually curated the data (e.g with phy?")
 
         # HWPD 20200527
@@ -187,6 +205,8 @@ class OpenEphysBase(FigureMaker):
         self.rawData = None
         self.xy = None
         self.xyTS = None
+        self.sync_message_file = None
+        self.ap_sample_rate = 30000
         self.recording_start_time = 0
         self.ts = None
         self.ttl_data = None
@@ -223,6 +243,60 @@ class OpenEphysBase(FigureMaker):
         # Overridden by sub-classes
         pass
 
+    def loadPos(self, *args, **kwargs):
+        # Only sub-class that doesn't use this is OpenEphysNWB
+        # which needs updating
+        # TODO: Update / overhaul OpenEphysNWB
+        # Load the start time from the sync_messages file
+        recording_start_time = 0
+        if self.sync_message_file is not None:
+            with open(self.sync_message_file, 'r') as f:
+                sync_strs = f.read()
+            sync_lines = sync_strs.split('\n')
+            for line in sync_lines:
+                if 'subProcessor: 0' in line:
+                    idx = line.find('start time: ')
+                    start_val = line[idx + len('start time: '):-1]
+                    tmp = start_val.split('@')
+                    recording_start_time = float(tmp[0])
+        if self.path2PosData is not None:
+            pos_data_type = getattr(self, 'pos_data_type', 'PosTracker')
+            if pos_data_type == 'PosTracker':
+                pos_data = np.load(os.path.join(
+                    self.path2PosData, 'data_array.npy'))
+            if pos_data_type == 'TrackingPlugin':
+                pos_data = loadTrackingPluginData(os.path.join(
+                    self.path2PosData, 'data_array.npy'))
+            pos_ts = np.load(os.path.join(
+                self.path2PosData, 'timestamps.npy'))
+            pos_ts = np.ravel(pos_ts)
+            default_pos_sample_rate = np.floor(1/np.mean(np.diff(pos_ts) /
+                                               self.ap_sample_rate))
+            sample_rate = getattr(self, 'pos_sample_rate',
+                                  default_pos_sample_rate)
+            self.xyTS = pos_ts - recording_start_time
+            pos_timebase = getattr(self, 'pos_timebase', 3e4)
+            self.xyTS = self.xyTS / pos_timebase  # convert to seconds
+            if self.sync_message_file is not None:
+                recording_start_time = self.xyTS[0]
+            self.pos_sample_rate = sample_rate
+            self.orig_x = pos_data[:, 0]
+            self.orig_y = pos_data[:, 1]
+
+            P = PosCalcsGeneric(
+                pos_data[:, 0], pos_data[:, 1], cm=True, ppm=self.ppm,
+                jumpmax=self.jumpmax)
+            xy, hdir = P.postprocesspos({'SampleRate': sample_rate})
+            setattr(self, 'PosCalcs', P)
+            self.xy = xy
+            self.dir = hdir
+            self.speed = P.speed
+        else:
+            warnings.warn("Could not find the pos data. \
+                Make sure there is a pos_data folder with data_array.npy \
+                and timestamps.npy in")
+        self.recording_start_time = recording_start_time
+
     def loadKilo(self, **kwargs):
         import os
         if 'pname' in kwargs:
@@ -297,8 +371,6 @@ class OpenEphysBase(FigureMaker):
                 data = data.T
             np.savetxt(out_fname, data, delimiter='\t')
 
-    
-    
     def filterPosition(self, filter_dict: dict):
         if hasattr(self, 'PosCalcs'):
             P = getattr(self, 'PosCalcs')
@@ -311,8 +383,8 @@ class OpenEphysBase(FigureMaker):
         '''
         Returns the spike times in seconds of the given cluster
         '''
-        spk_times = self.kilodata.spk_times.T
-        return spk_times[self.kilodata.spk_clusters == cluster].astype(np.int64)
+        times = self.kilodata.spk_times.T
+        return times[self.kilodata.spk_clusters == cluster].astype(np.int64)
 
     def plotSummary(self, cluster: int, **kwargs):
         ts = self.getClusterSpikeTimes(cluster)
@@ -465,8 +537,7 @@ class OpenEphysNPX(OpenEphysBase):
         import re
         APdata_match = re.compile('Neuropix-PXI-[0-9][0-9][0-9].0')
         LFPdata_match = re.compile('Neuropix-PXI-[0-9][0-9][0-9].1')
-        PosTracker_match = re.compile('Pos_Tracker-[0-9][0-9][0-9].[0-9]/BINARY_group_[0-9]')
-        sync_message_file = None
+        self.sync_message_file = None
         self.recording_start_time = None
         ap_sample_rate = getattr(self, 'ap_sample_rate', 30000)
 
@@ -477,40 +548,35 @@ class OpenEphysNPX(OpenEphysBase):
             for ff in f:
                 if '.' not in c:  # ignore hidden directories
                     if 'data_array.npy' in ff:
-                        if PosTracker_match.search(d):
+                        if PurePath(d).match('*Pos_Tracker*/BINARY_group*'):
                             if self.path2PosData is None:
                                 self.path2PosData = os.path.join(d)
+                                print(f"Found pos data at: {self.path2PosData}")
                             self.path2PosOEBin = Path(d).parents[1]
+                        if PurePath(d).match('*pos_data*'):
+                            if self.path2PosData is None:
+                                self.path2PosData = os.path.join(d)
+                                print(f"Found pos data at: {self.path2PosData}")
+                        if PurePath(d).match('*Tracking_Port*/BINARY_group*'):
+                            if self.path2PosData is None:
+                                self.path2PosData = os.path.join(d)
+                                print(f"Found pos data at: {self.path2PosData}")
                     if 'continuous.dat' in ff:
                         if APdata_match.search(d):
                             self.path2APdata = os.path.join(d)
+                            print(f"Found continuous data at: {self.path2APdata}")
                             self.path2APOEBin = Path(d).parents[1]
                         if LFPdata_match.search(d):
                             self.path2LFPdata = os.path.join(d)
+                            print(f"Found continuous data at: {self.path2LFPdata}")
                     if 'sync_messages.txt' in ff:
                         sync_file = os.path.join(
                             d, 'sync_messages.txt')
                         if fileContainsString(sync_file, 'Processor'):
-                            sync_message_file = sync_file
+                            self.sync_message_file = sync_file
+                            print(f"Found sync_messages file at: {sync_file}")
 
-        if self.path2PosData is not None:
-            pos_data = np.load(os.path.join(
-                self.path2PosData, 'data_array.npy'))
-            pos_ts = np.load(os.path.join(self.path2PosData, 'timestamps.npy'))
-            pos_ts = np.ravel(pos_ts)
-            sample_rate = np.floor(1/np.mean(np.diff(pos_ts)/ap_sample_rate))
-            self.xyTS = pos_ts# / ap_sample_rate
-            self.pos_sample_rate = sample_rate
-            self.orig_x = pos_data[:, 0]
-            self.orig_y = pos_data[:, 1]
-
-            P = PosCalcsGeneric(
-                pos_data[:, 0], pos_data[:, 1], cm=True, ppm=self.ppm, jumpmax=self.jumpmax)
-            xy, hdir = P.postprocesspos({'SampleRate': sample_rate})
-            setattr(self, 'PosCalcs', P)
-            self.xy = xy
-            self.dir = hdir
-            self.speed = P.speed
+        self.loadPos()
 
         n_channels = getattr(self, 'n_channels', 384)
         trial_length = 0  # make sure a trial_length has a value
@@ -519,26 +585,13 @@ class OpenEphysNPX(OpenEphysBase):
                 trial_length = self.__calcTrialLengthFromBinarySize__(
                     os.path.join(self.path2APdata, 'continuous.dat'),
                     n_channels, ap_sample_rate)
-        # Load the start time from the sync_messages file
-        if sync_message_file is not None:
-            with open(sync_message_file, 'r') as f:
-                sync_strs = f.read()
-            sync_lines = sync_strs.split('\n')
-            for line in sync_lines:
-                if 'subProcessor: 0' in line:
-                    idx = line.find('start time: ')
-                    start_val = line[idx + len('start time: '):-1]
-                    tmp = start_val.split('@')
-                    recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
-        else:
-            recording_start_time = self.xyTS[0]
-        self.recording_start_time = recording_start_time
+       
         # this way of creating timestamps will be fine for single probes
         # but will need to be modified if using multiple probes and/ or 
         # different timestamp syncing method
         # OE's 'synchronised_timestamps.npy' should now take care of this
         self.ts = np.arange(
-            recording_start_time, trial_length+recording_start_time,
+            self.recording_start_time, trial_length+self.recording_start_time,
             1.0 / ap_sample_rate)
 
     def plotSpectrogramByDepth(
@@ -580,8 +633,9 @@ class OpenEphysNPX(OpenEphysBase):
             lfp_file, np.int16, 'r', 0, (nchannels, nsamples), order='F')
         # Load the channel map
         #  Assumes this is in the AP data location and that kilosort was run
-        channel_map = np.squeeze(np.load(os.path.join(
-            self.path2APdata, 'channel_map.npy')))
+        # channel_map = np.squeeze(np.load(os.path.join(
+        #     self.path2APdata, 'channel_map.npy')))
+        channel_map = np.arange(nchannels)
         lfp_sample_rate = 2500
         data = np.array(mmap[channel_map, 0:nseconds*lfp_sample_rate])
         from ephysiopy.common.ephys_generic import EEGCalcsGeneric
@@ -655,6 +709,8 @@ class OpenEphysNPX(OpenEphysBase):
 
         cols = iter(cm.nipy_spectral(np.linspace(0, 1, len(upper_freqs))))
         mn_power = np.mean(spec_data, 1)
+        print(f"spec_data shape = {np.shape(spec_data)}")
+        print(f"mn_power shape = {np.shape(mn_power)}")
         for freqs in zip(lower_freqs, upper_freqs):
             freq_mask = np.logical_and(
                 E.freqs[0::50] > freqs[0],
@@ -843,8 +899,10 @@ class OpenEphysBinary(OpenEphysBase):
         import re
         APdata_match = re.compile('Rhythm_FPGA-[0-9][0-9][0-9].0')
         LFPdata_match = re.compile('Rhythm_FPGA-[0-9][0-9][0-9].1')
-        sync_message_file = None
+        PosTracker_match = re.compile('Pos_Tracker-[0-9][0-9][0-9].[0-9]/BINARY_group_[0-9]')
+        self.sync_message_file = None
         self.recording_start_time = None
+        ap_sample_rate = getattr(self, 'ap_sample_rate', 30000)
 
         if pname_root is None:
             pname_root = self.pname_root
@@ -853,25 +911,29 @@ class OpenEphysBinary(OpenEphysBase):
             for ff in f:
                 if '.' not in c:  # ignore hidden directories
                     if 'data_array.npy' in ff:
-                        self.path2PosData = os.path.join(d)
+                        if PurePath(d).match('*Pos_Tracker*/BINARY_group*'):
+                            self.path2PosData = os.path.join(d)
+                            print(f"Found pos data at: {self.path2PosData}")
+                            self.path2PosOEBin = Path(d).parents[1]
                     if 'continuous.dat' in ff:
                         if APdata_match.search(d):
                             self.path2APdata = os.path.join(d)
+                            print(f"Found continuous data at: {self.path2APdata}")
+                            self.path2APOEBin = Path(d).parents[1]
                         if LFPdata_match.search(d):
                             self.path2LFPdata = os.path.join(d)
+                            print(f"Found continuous data at: {self.path2LFPdata}")
                     if 'sync_messages.txt' in ff:
-                        sync_message_file = os.path.join(
+                        sync_file = os.path.join(
                             d, 'sync_messages.txt')
+                        if fileContainsString(sync_file, 'Processor'):
+                            self.sync_message_file = sync_file
+                            print(f"Found sync_messages file at: {sync_file}")
 
-        if self.path2PosData is not None:
-            pos_data = np.load(os.path.join(
-                self.path2PosData, 'data_array.npy'))
-            self.xy = pos_data[:, 0:2].T
-            pos_ts = np.load(os.path.join(
-                self.path2PosData, 'timestamps.npy'))
-            self.xyTS = pos_ts / 30.0 / 1000.0
+        self.loadPos()
 
-        ap_sample_rate = 30000
+        n_channels = getattr(self, 'n_channels', 384)
+        trial_length = 0  # make sure a trial_length has a value
         if fileExists(self.path2APdata, 'continuous.dat'):
             trial_length = self.__calcTrialLengthFromBinarySize__(
                 os.path.join(self.path2APdata, 'continuous.dat'),
@@ -887,22 +949,10 @@ class OpenEphysBinary(OpenEphysBase):
                     np.int16, 'r', 0, (n_channels, n_samples), 'C')
                 self.rawData = np.array(mmap, dtype=np.float64)
 
-        # Load the start time from the sync_messages file
-        recording_start_time = 0
-        if sync_message_file is not None:
-            with open(sync_message_file, 'r') as f:
-                sync_strs = f.read()
-            sync_lines = sync_strs.split('\n')
-            for line in sync_lines:
-                if 'subProcessor: 0' in line:
-                    idx = line.find('start time: ')
-                    start_val = line[idx + len('start time: '):-1]
-                    tmp = start_val.split('@')
-                    recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
-            self.xyTS = self.xyTS - recording_start_time  # zero pos timestamps
-        else:
-            recording_start_time = self.xyTS[0]
-        self.recording_start_time = recording_start_time
+        # this way of creating timestamps will be fine for single probes
+        # but will need to be modified if using multiple probes and/ or 
+        # different timestamp syncing method
+        # OE's 'synchronised_timestamps.npy' should now take care of this
         self.ts = np.arange(
-            recording_start_time, trial_length+recording_start_time,
-            1.0 / ap_sample_rate)
+            self.recording_start_time, trial_length+self.recording_start_time,
+            1.0 / ap_sample_rate)
\ No newline at end of file
