@@ -51,18 +51,18 @@ class FigureMaker(object):
                 pos_weights = np.ones_like(hdir)
         ppm = getattr(self, 'ppm', 300)
         cmsPerBin = getattr(self, 'cmsPerBin', 3)
-        
+
         self.RateMapMaker = RateMap(
             xy=xy, hdir=hdir, speed=speed, pos_weights=pos_weights, ppm=ppm,
             xyInCms=True, cmsPerBin=cmsPerBin)
-        self.RateMapMaker.x_lims = getattr(self, 'x_lims', None) # 2-tuple
+        self.RateMapMaker.x_lims = getattr(self, 'x_lims', None)  # 2-tuple
         self.RateMapMaker.y_lims = getattr(self, 'y_lims', None)
         self.data_loaded = True
 
     def getSpikePosIndices(self, spk_times: np.array):
         pos_times = getattr(self, 'xyTS')
         idx = np.searchsorted(pos_times, spk_times)
-        idx[idx==len(pos_times)] = idx[idx==len(pos_times)] - 1
+        idx[idx == len(pos_times)] = idx[idx == len(pos_times)] - 1
         return idx
 
     def makeSummaryPlot(self, spk_times: np.array):
@@ -81,14 +81,15 @@ class FigureMaker(object):
         return fig
 
     @stripAxes
-    def makeRateMap(self, spk_times: np.array, ax: matplotlib.axes=None) -> matplotlib.axes:
+    def makeRateMap(self, spk_times: np.array,
+                    ax: matplotlib.axes = None) -> matplotlib.axes:
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
             spk_times_in_pos_samples, minlength=self.npos)
         rmap = self.RateMapMaker.getMap(spk_weights)
         ratemap = np.ma.MaskedArray(rmap[0], np.isnan(rmap[0]), copy=True)
-        x, y = np.meshgrid(rmap[1][1][0:-1], rmap[1][0][0:-1][::-1])
+        x, y = np.meshgrid(rmap[1][1][0:-1], rmap[1][0][0:-1])
         vmax = np.nanmax(np.ravel(ratemap))
         if ax is None:
             fig = plt.figure()
@@ -96,13 +97,13 @@ class FigureMaker(object):
         ax.pcolormesh(
             x, y, ratemap, cmap=plt.cm.get_cmap("jet"), edgecolors='face',
             vmax=vmax, shading='auto')
-        # ax.axis([x.min(), x.max(), y.min(), y.max()])
         ax.set_aspect('equal')
         return ax
 
     @stripAxes
-    def makeSpikePathPlot(
-        self, spk_times: np.array = None, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def makeSpikePathPlot(self, spk_times: np.array = None,
+                          ax: matplotlib.axes = None,
+                          **kwargs) -> matplotlib.axes:
         self.initialise()
         if 'c' in kwargs:
             col = kwargs.pop('c')
@@ -111,9 +112,8 @@ class FigureMaker(object):
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
-        ax.plot(self.xy[0], self.xy[1], c=tcols.colours[0], zorder=1)
+        ax.plot(self.xy[0, :], self.xy[1, :], c=tcols.colours[0], zorder=1)
         ax.set_aspect('equal')
-        ax.invert_yaxis()
         if spk_times is not None:
             idx = self.getSpikePosIndices(spk_times)
             ax.plot(
@@ -121,8 +121,8 @@ class FigureMaker(object):
         return ax
 
     @stripAxes
-    def makeSAC(
-        self, spk_times: np.array = None, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def makeSAC(self, spk_times: np.array = None,
+                ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
@@ -140,8 +140,8 @@ class FigureMaker(object):
         return ax
 
     @stripAxes
-    def makeHDPlot(
-        self, spk_times: np.array = None, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def makeHDPlot(self, spk_times: np.array = None,
+                   ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         spk_weights = np.bincount(
@@ -176,9 +176,9 @@ class FigureMaker(object):
 
     @stripAxes
     def makeSpeedVsRatePlot(
-            self, spk_times: np.array, minSpeed: float=0.0,
-            maxSpeed: float=40.0, sigma: float=3.0,
-            ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+            self, spk_times: np.array, minSpeed: float = 0.0,
+            maxSpeed: float = 40.0, sigma: float = 3.0,
+            ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
         """
         Plots the instantaneous firing rate of a cell against running speed
         Also outputs a couple of measures as with Kropff et al., 2015; the
@@ -187,7 +187,7 @@ class FigureMaker(object):
         """
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
-        
+
         speed = np.ravel(self.speed)
         if np.nanmax(speed) < maxSpeed:
             maxSpeed = np.nanmax(speed)
@@ -223,12 +223,17 @@ class FigureMaker(object):
         return ax
 
     @stripAxes
-    def makeSpeedVsHeadDirectionPlot(
-            self, spk_times: np.array, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def makeSpeedVsHeadDirectionPlot(self, spk_times: np.array,
+                                     ax: matplotlib.axes = None,
+                                     **kwargs) -> matplotlib.axes:
         self.initialise()
         spk_times_in_pos_samples = self.getSpikePosIndices(spk_times)
         idx = np.array(spk_times_in_pos_samples, dtype=int)
-        w = np.bincount(idx, minlength=self.speed.shape[0])
+        if np.ma.is_masked(self.speed):
+            w = self.speed.mask
+            w = np.array(~w, dtype=int)
+        else:
+            w = np.bincount(idx, minlength=self.speed.shape[0])
         dir_bins = np.arange(0, 360, 6)
         spd_bins = np.arange(0, 30, 1)
         h = np.histogram2d(
@@ -244,8 +249,9 @@ class FigureMaker(object):
         if ax is None:
             fig = plt.figure()
             ax = fig.add_subplot(111)
-        ax.pcolormesh(x, y, im.T, cmap=plt.cm.get_cmap("jet"), edgecolors='face',
-            vmax=vmax, shading='auto')
+        ax.pcolormesh(x, y, im.T, cmap=plt.cm.get_cmap("jet"),
+                      edgecolors='face',
+                      vmax=vmax, shading='auto')
         plt.xticks([90, 180, 270], fontweight='normal', size=6)
         plt.yticks([10, 20], fontweight='normal', size=6)
         return ax
@@ -253,8 +259,8 @@ class FigureMaker(object):
     def makePowerSpectrum(
             self, freqs: np.array, power: np.array, sm_power: np.array,
             band_max_power: float, freq_at_band_max_power: float,
-            max_freq: int=50, theta_range: tuple=[6, 12],
-            ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+            max_freq: int = 50, theta_range: tuple = [6, 12],
+            ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
         # downsample frequencies and power
         freqs = freqs[0::50]
         power = power[0::50]
@@ -281,8 +287,8 @@ class FigureMaker(object):
         ax.add_patch(r)
         return ax
 
-    def makeXCorr(
-        self, spk_times: np.array, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def makeXCorr(self, spk_times: np.array, ax: matplotlib.axes = None,
+                  **kwargs) -> matplotlib.axes:
         # spk_times in samples provided in seconds but convert to
         # ms for a more display friendly scale
         spk_times = spk_times / 3e4 * 1000.
@@ -307,10 +313,10 @@ class FigureMaker(object):
         ax.xaxis.set_ticks_position('bottom')
         return ax
 
-    def makeRaster(
-            self, spk_times: np.array, dt=(-50, 100), prc_max: float=0.5,
-            ax: matplotlib.axes=None, ms_per_bin: int=1,
-            histtype: str='count', **kwargs) -> matplotlib.axes:
+    def makeRaster(self, spk_times: np.array, dt=(-50, 100),
+                   prc_max: float = 0.5, ax: matplotlib.axes = None,
+                   ms_per_bin: int = 1, histtype: str = 'count',
+                   **kwargs) -> matplotlib.axes:
         """
         Plots a raster plot for a specified tetrode/ cluster
 
@@ -421,7 +427,7 @@ class FigureMaker(object):
             dt=(-50, 100), hist=True):
         """
         MOVE TO SPIKECALCS
-        
+
         Calculates the histogram of the raster of spikes during a series of
         events
 
@@ -460,8 +466,8 @@ class FigureMaker(object):
     '''
 
     @stripAxes
-    def show_SAC(
-        self, A: np.array, inDict: dict, ax: matplotlib.axes=None, **kwargs) -> matplotlib.axes:
+    def show_SAC(self, A: np.array, inDict: dict,
+                 ax: matplotlib.axes = None, **kwargs) -> matplotlib.axes:
         """
         Displays the result of performing a spatial autocorrelation (SAC)
         on a grid cell.
@@ -495,10 +501,8 @@ class FigureMaker(object):
         Am[~inDict['dist_to_centre']] = np.nan
         Am = np.ma.masked_invalid(np.atleast_2d(Am))
         x, y = np.meshgrid(
-            np.arange(0, np.shape(A)[0]),
-            np.arange(0, np.shape(A)[1]))
-        x = x.T
-        y = y.T
+            np.arange(0, np.shape(A)[1]),
+            np.arange(0, np.shape(A)[0]))
         vmax = np.nanmax(np.ravel(A))
         ax.pcolormesh(
             x, y, A, cmap=plt.cm.get_cmap("gray_r"),
@@ -510,7 +514,9 @@ class FigureMaker(object):
             x, y, Am, cmap=cmap,
             edgecolors='face', vmax=vmax, shading='auto')
         # horizontal green line at 3 o'clock
-        ax.axhline(y=np.shape(A)[0]/2, c='g')
+        _y = (np.shape(A)[0]/2, np.shape(A)[0]/2)
+        _x = (np.shape(A)[1]/2, np.shape(A)[0])
+        ax.plot(_x, _y, c='g')
         mag = inDict['scale'] * 0.5
         th = np.linspace(0, inDict['orientation'], 50)
         from ephysiopy.common.utils import rect
@@ -525,11 +531,11 @@ class FigureMaker(object):
                 ax.plot(
                     (inDict['dist_to_centre'].shape[1]/2, p[1]),
                     (inDict['dist_to_centre'].shape[0] / 2, p[0]), 'k', **kwargs)
-        # ax.invert_yaxis()
-        # all_ax = ax.axes
-        # all_ax.set_aspect('equal')
-        # all_ax.set_xlim((0.5, inDict['dist_to_centre'].shape[1]-1.5))
-        # all_ax.set_ylim((inDict['dist_to_centre'].shape[0]-.5, -.5))
+        ax.invert_yaxis()
+        all_ax = ax.axes
+        all_ax.set_aspect('equal')
+        all_ax.set_xlim((0.5, inDict['dist_to_centre'].shape[1]-1.5))
+        all_ax.set_ylim((inDict['dist_to_centre'].shape[0]-.5, -.5))
         return ax
     '''
     def plotDirFilteredRmaps(self, tetrode, cluster, maptype='rmap', **kwargs):
